@@ -7,7 +7,7 @@
 #' - **Fashion-MNIST**: Clothing item images for classification.
 #' - **Kuzushiji-MNIST**: Japanese cursive character dataset.
 #' - **QMNIST**: Extended MNIST with high-precision NIST data.
-#' - **EMNIST**: Letters and digits with multiple label splits.
+#' - **EMNIST**: A collection of letters and digits with multiple datasets and  splits.
 #'
 #' @param root Root directory for dataset storage. The dataset will be stored under `root/<dataset-name>`. Defaults to `tempdir()`.
 #' @param train Logical. If TRUE, use the training set; otherwise, use the test set. Not applicable to all datasets.
@@ -18,7 +18,7 @@
 #'
 #' @return A torch dataset object, where each items is a list of `x` (image) and `y` (label).
 #'
-#' @section Supported Splits for `emnist_dataset()`:
+#' @section Supported `dataset`s for `emnist_collection()`:
 #' - `"byclass"`: 62 classes (digits + uppercase + lowercase)
 #' - `"bymerge"`: 47 classes (merged uppercase and lowercase)
 #' - `"balanced"`: 47 classes, balanced digits and letters
@@ -26,7 +26,7 @@
 #' - `"digits"`: 10 digit classes
 #' - `"mnist"`: Standard MNIST digit classes
 #'
-#' @section Supported Splits for `qmnist_dataset()`:
+#' @section Supported `split`s for `qmnist_dataset()`:
 #' - `"train"`: 60,000 training samples (MNIST-compatible)
 #' - `"test"`: Extended test set
 #' - `"nist"`: Full NIST digit set
@@ -43,13 +43,13 @@
 #' item$x
 #' item$y
 #'
-#' emnist <- emnist_dataset(split = "balanced", download = TRUE)
+#' emnist <- emnist_collection(dataset = "balanced", split = "test", download = TRUE)
 #' item <- emnist[1]
 #' item$x
 #' item$y
 #'
-#' kmnist <- kmnist_dataset(download = TRUE)
-#' fmnist <- fashion_mnist_dataset(download = TRUE)
+#' kmnist <- kmnist_dataset(download = TRUE, train = FALSE)
+#' fmnist <- fashion_mnist_dataset(download = TRUE, train = TRUE)
 #' }
 #'
 #' @family classification_dataset
@@ -141,10 +141,12 @@ mnist_dataset <- dataset(
     cli_inform("Dataset {.cls {class(self)[[1]]}} downloaded and extracted successfully.")
 
   },
+
   check_exists = function() {
     fs::file_exists(file.path(self$processed_folder, self$training_file)) &&
       fs::file_exists(file.path(self$processed_folder, self$test_file))
   },
+
   .getitem = function(index) {
     x <- self$data[index, ,]
     y <- self$targets[index]
@@ -157,9 +159,28 @@ mnist_dataset <- dataset(
 
     list(x = x, y = y)
   },
+
+  .getbatch = function(index) {
+    x <- self$data[index, ,]
+    if (length(index) > 1) {
+      x <-  aperm(x, c(2, 3, 1))
+    }
+
+    y <- self$targets[index]
+
+    if (!is.null(self$transform))
+      x <- self$transform(x)
+
+    if (!is.null(self$target_transform))
+      y <- self$target_transform(y)
+
+    list(x = x, y = y)
+  },
+
   .length = function() {
     dim(self$data)[1]
   },
+
   active = list(
     raw_folder = function() {
       file.path(self$root_path, "mnist", "raw")
@@ -190,6 +211,7 @@ kmnist_dataset <- dataset(
 #' @export
 qmnist_dataset <- dataset(
   name = "qmnist_dataset",
+  inherit = mnist_dataset,
   archive_size = "70 MB",
 
   resources = list(
@@ -304,23 +326,6 @@ qmnist_dataset <- dataset(
     fs::file_exists(file.path(self$processed_folder, self$files[[self$split]]))
   },
 
-  .getitem = function(index) {
-    x <- self$data[index, ,]
-    y <- self$targets[index]
-
-    if (!is.null(self$transform))
-      x <- self$transform(x)
-
-    if (!is.null(self$target_transform))
-      y <- self$target_transform(y)
-
-    list(x = x, y = y)
-  },
-
-  .length = function() {
-    dim(self$data)[1]
-  },
-
   active = list(
     raw_folder = function() {
       file.path(self$root_path, "qmnist", "raw")
@@ -331,28 +336,6 @@ qmnist_dataset <- dataset(
   )
 )
 
-read_sn3_pascalvincent <- function(path) {
-  x <- gzfile(path, open = "rb")
-  on.exit({close(x)})
-
-  magic <- readBin(x, endian = "big", what = integer(), n = 1)
-  n_dimensions <- magic %% 256
-  ty <- magic %/% 256
-
-  dim <- readBin(x, what = integer(), size = 4, endian = "big",
-          n = n_dimensions)
-
-  a <- readBin(
-    x,
-    what = "int", endian = "big", n = prod(dim),
-    size = 1, signed = FALSE
-  )
-
-  a <- array(a, dim = rev(dim))
-  a <- aperm(a, perm = rev(seq_along(dim)))
-  a
-}
-
 #' @describeIn mnist_dataset Fashion-MNIST clothing image dataset.
 #' @export
 fashion_mnist_dataset <- dataset(
@@ -371,17 +354,19 @@ fashion_mnist_dataset <- dataset(
   )
 )
 
-#' @describeIn mnist_dataset EMNIST dataset with digits and letters and multiple split modes.
+#' @describeIn mnist_dataset EMNIST collection with digits and letters arranged in multiple datasets.
+#' @param dataset one of "byclass", "bymerge", "balanced" representing the subset of emnist collection
+#' made of a set of classes. You can look at dataset attribute `$classes` to see the actual classes.
 #' @export
-emnist_dataset <- dataset(
-  name = "emnist_dataset",
+emnist_collection <- dataset(
+  name = "emnist_collection",
   archive_size = "540 MB",
+
   resources = list(
     c("https://biometrics.nist.gov/cs_links/EMNIST/gzip.zip", "58c8d27c78d21e728a6bc7b3cc06412e")
   ),
-  training_file = function(split) glue::glue("training-{split}.rds"),
-  test_file = function(split) glue::glue("test-{split}.rds"),
-  classes_list = list(
+  rds_file = function(split, kind) paste0(split,"-",kind,".rds"),
+  classes_all_dataset = list(
     byclass = c(
       "0","1","2","3","4","5","6","7","8","9",
       LETTERS,
@@ -404,40 +389,35 @@ emnist_dataset <- dataset(
 
   initialize = function(
     root = tempdir(),
-    split = "balanced",
+    split = "test",
+    dataset = "balanced",
     transform = NULL,
     target_transform = NULL,
     download = FALSE
   ) {
 
-    split <- match.arg(split, choices = names(self$classes_list))
-    self$split <- split
+    self$split <- match.arg(split, choices = c("train", "test"))
+    self$dataset <- match.arg(dataset,  choices = names(self$classes_all_dataset))
     self$root_path <- root
+    self$raw_folder <- file.path(root, class(self)[1], "raw")
+    self$processed_folder <- file.path(root, class(self)[1], "processed")
     self$transform <- transform
     self$target_transform <- target_transform
-    self$classes <- self$classes_list[[split]]
+    self$class <- self$classes_all_dataset[[self$dataset]]
 
-    if (download){
-      cli_inform("Dataset {.cls {class(self)[[1]]}} (~{.emph {self$archive_size}}) will be downloaded and processed if not already available.")
+    if (download) {
+      cli_inform("{.cls {class(self)[[1]]}} (~{.emph {self$archive_size}}) will be downloaded and processed if not already available.")
       self$download()
     }
 
     if (!self$check_exists())
       runtime_error("Dataset not found. You can use `download = TRUE` to download it.")
 
-    file_to_load_train <- self$training_file(split)
-    file_to_load_test <- self$test_file(split)
+    dataset_lst <- readRDS(file.path(self$processed_folder, self$rds_file(self$split, self$dataset)))
+    self$data <- dataset_lst[[1]]
+    self$targets <- dataset_lst[[2]] + 1L
 
-    training_data <- readRDS(file.path(self$processed_folder, file_to_load_train))
-    test_data <- readRDS(file.path(self$processed_folder, file_to_load_test))
-
-    self$data <- training_data[[1]]
-    self$targets <- training_data[[2]] + 1L
-    self$test_data <- test_data[[1]]
-    self$test_targets <- test_data[[2]] + 1L
-
-    self$is_train <- TRUE
-    cli_inform("{.cls {class(self)[[1]]}} dataset processed successfully!")
+    cli_inform("Split {.val {self$split}} of dataset {.val {self$dataset}} from {.cls {class(self)[[1]]}} processed successfully!")
   },
 
   download = function() {
@@ -456,41 +436,25 @@ emnist_dataset <- dataset(
     fs::dir_create(unzip_dir)
     unzip(archive, exdir = unzip_dir)
 
+    # unzip second level of archives
     unzipped_root <- fs::dir_ls(unzip_dir, type = "directory", recurse = FALSE)[1]
 
-    process_split <- function(split_name) {
-      train_img <- file.path(unzipped_root, glue::glue("emnist-{split_name}-train-images-idx3-ubyte.gz"))
-      train_lbl <- file.path(unzipped_root, glue::glue("emnist-{split_name}-train-labels-idx1-ubyte.gz"))
-      test_img  <- file.path(unzipped_root, glue::glue("emnist-{split_name}-test-images-idx3-ubyte.gz"))
-      test_lbl  <- file.path(unzipped_root, glue::glue("emnist-{split_name}-test-labels-idx1-ubyte.gz"))
+    # only manage extraction of the 2 ubyte.gz under interest
+    img <- file.path(unzipped_root, glue::glue("emnist-{self$dataset}-{self$split}-images-idx3-ubyte.gz"))
+    lbl <- file.path(unzipped_root, glue::glue("emnist-{self$dataset}-{self$split}-labels-idx1-ubyte.gz"))
+    dataset_set <- list(read_sn3_pascalvincent(img), read_sn3_pascalvincent(lbl))
+    saveRDS(dataset_set, file.path(self$processed_folder, self$rds_file(self$split, self$dataset)))
 
-      train_set <- list(read_sn3_pascalvincent(train_img),
-                        read_sn3_pascalvincent(train_lbl))
-      test_set <- list(read_sn3_pascalvincent(test_img),
-                       read_sn3_pascalvincent(test_lbl))
-
-      saveRDS(train_set, file.path(self$processed_folder, self$training_file(split_name)))
-      saveRDS(test_set, file.path(self$processed_folder, self$test_file(split_name)))
-    }
-
-    for (split_name in names(self$classes_list)) {
-      process_split(split_name)
-    }
   },
-
+  # only manage existence of the rds file under interest
   check_exists = function() {
-    all(sapply(names(self$classes_list), function(split_name) {
-      fs::file_exists(file.path(self$processed_folder, self$training_file(split_name))) &&
-      fs::file_exists(file.path(self$processed_folder, self$test_file(split_name)))
-    }))
+    fs::file_exists(file.path(self$processed_folder, self$rds_file(self$split, self$dataset)))
   },
 
   .getitem = function(index) {
-    data_set <- if (self$is_train) self$data else self$test_data
-    targets_set <- if (self$is_train) self$targets else self$test_targets
 
-    x <- data_set[index, , ]
-    y <- targets_set[index]
+    x <- self$data[index, , ]
+    y <- self$targets[index]
 
     if (!is.null(self$transform))
       x <- self$transform(x)
@@ -502,23 +466,9 @@ emnist_dataset <- dataset(
   },
 
   .length = function() {
-    data_set <- if (self$is_train) self$data else self$test_data
-    dim(data_set)[1]
-  },
-
-  active = list(
-    raw_folder = function() {
-      file.path(self$root_path, "emnist", "raw")
-    },
-    processed_folder = function() {
-      file.path(self$root_path, "emnist", "processed")
-    }
-  ),
-
-  set_train = function(train = TRUE) {
-    self$is_train <- train
-    invisible(self)
+    dim(self$data)[1]
   }
+
 )
 
 read_sn3_pascalvincent <- function(path) {
@@ -542,3 +492,12 @@ read_sn3_pascalvincent <- function(path) {
   a <- aperm(a, perm = rev(seq_along(dim)))
   a
 }
+
+#' @describeIn mnist_dataset Deprecated. Please use emnist_collection.
+#' @param kind the `dataset` in `emnist_collection`.
+#' @param ... the other `emnist_collection` parameters.
+#' @export
+emnist_dataset <- function(kind, ...){
+  .Deprecated("emnist_collection")
+  emnist_collection(dataset = kind, ...)
+}
