@@ -25,3 +25,13 @@ download_and_cache <- function(url, redownload = FALSE, prefix = NULL) {
 
   path
 }
+
+
+# add additional checks to release issues created with usethis::use_release_issue()
+# https://usethis.r-lib.org/reference/use_release_issue.html
+release_bullets <- function() {
+  c("Update `po/R-torchvision.pot` file with `potools::po_update()`",
+    "Contact translators to collect their translation `.po` files",
+    "Compile the translations with `potools::po_compile()`"
+  )
+}
