@@ -18,16 +18,14 @@ test_that("vgg models works", {
 
   }
 
-  skip_on_ci() # unfortunatelly we don't have anough RAM on CI for that.
+  skip_on_ci() # unfortunatelly we don't have enough RAM on CI for that.
   #skip_on_os(os = "mac") # not downloading a bunch of files locally.
   #skip_on_os(os = "windows") # not downloading a bunch of files locally.
 
   for (m in vggs) {
     model <- m(pretrained = TRUE)
     expect_tensor_shape(model(torch_ones(1, 3, 224, 224)), c(1, 1000))
-
-    rm(model)
     gc()
   }
-
+  unlink_model_file()
 })
